@@ -1,3 +1,5 @@
+use downcast_rs::{Downcast, impl_downcast};
+
 use ross_protocol::packet::Packet;
 
 use crate::state::StateManager;
@@ -11,7 +13,10 @@ pub use bcm_change_brightness_producer::*;
 mod none_producer;
 pub use none_producer::*;
 
-pub trait Producer {
+pub const BCM_CHANGE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0000;
+pub const BCM_CHANGE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0001;
+
+pub trait Producer: Downcast {
     fn produce(
         &self,
         value: &Value,
@@ -19,3 +24,5 @@ pub trait Producer {
         device_address: u16,
     ) -> Option<Packet>;
 }
+
+impl_downcast!(Producer);
